@@ -2,10 +2,12 @@ from .base import BaseTokenizer
 from .default import DefaultTokenizer
 from .nltk import NLTKTokenizer
 from .partitioner import PartitionTokenizer
+from .wrapper import LambdaTokenizer
 
 __all__ = [
     'BaseTokenizer',
     'DefaultTokenizer',
     'NLTKTokenizer',
     'PartitionTokenizer',
+    'LambdaTokenizer'
 ]
