@@ -156,7 +156,7 @@ def test_null_tweet(null_tweet):
     assert null_tweet.author is None
     assert null_tweet.created_at is None
     assert null_tweet.reply_to == set()
-    assert null_tweet.platform is None
+    assert null_tweet.platform == 'Twitter'
     assert null_tweet.tags == set()
     assert null_tweet.lang is None
 
@@ -168,7 +168,7 @@ def test_update_tweet(null_tweet, mock_json_tweet):
     null_tweet.author = mock_json_tweet['author']
     assert null_tweet.author == mock_json_tweet['author']
 
-    null_tweet.set_created_at(mock_json_tweet['created_at'])
+    null_tweet.created_at = mock_json_tweet['created_at']
     assert null_tweet.created_at.timestamp() == mock_json_tweet['created_at']
 
     for uid in mock_json_tweet['reply_to']:
@@ -233,9 +233,14 @@ def test_post_redaction(mock_tweet):
     mock_tweet.redact({'tweeter1': 'NAME2'})
     assert mock_tweet.author == 'NAME2'
 
+    mock_tweet.text = ''
+    mock_tweet.redact({'tweeter1': 'NAME2'})
+    assert mock_tweet.author == 'NAME2'
+    assert mock_tweet.text == ''
+
 
 def test_tweet_repr(mock_tweet):
-    assert mock_tweet.__repr__() == 'UniMessage(Twitter::tweeter1::9999999.0::This is a tweet! @Twitter::tags=test_tag)'
+    assert mock_tweet.__repr__() == 'Tweet(Twitter::tweeter1::9999999.0::This is a tweet! @Twitter::tags=test_tag)'
 
 
 def test_tweet_datetime_parsing(null_tweet):
@@ -244,11 +249,11 @@ def test_tweet_datetime_parsing(null_tweet):
     dt = 'Thu Dec 31 23:59:59 +0000 2020'
     assert datetime(2020, 12, 31, 23, 59, 59) == Tweet.parse_datestr(dt)
 
-    null_tweet.set_created_at(dt)
+    null_tweet.created_at = dt
     assert datetime(2020, 12, 31, 23, 59, 59) == null_tweet.created_at
 
     with pytest.raises(TypeError):
-        null_tweet.set_created_at({})
+        null_tweet.created_at = {}
 
 
 def test_read_raw_tweet(mock_raw_tweet):
